A Python library that format dates, numbers and text to conform with the Reuters Style Guide, the standards that guide the world's largest independent newsroom

## Links

- Documentation: [palewi.re/docs/reuters-style/](https://palewi.re/docs/reuters-style/)
- Code: [github.com/palewire/reuters-style](https://github.com/palewire/reuters-style)
- Issues: [github.com/palewire/reuters-style/issues](https://github.com/palewire/reuters-style/issues)
- Packaging: [pypi.org/project/reuters-style](https://pypi.org/project/reuters-style)
